--[[
Copyright (C) GtX (Andy), 2018

Interface: 1.5.3.1 b1848

Author: GtX	 @  LS-Modcompany
Date: 08.09.2018

Support only at: https://ls-modcompany.com

History:
Version: 1.0.0.0 - Release Edition @ 08.09.2018

Important:
No changes are to be made to this script without permission from GtX @ https://ls-modcompany.com
This includes converting to other game versions before or after FS/LS17

** PLACEABLE ONLY! **
]]

LetterboxGui = {};

local LetterboxGui_mt = Class(LetterboxGui, YesNoDialog);

function LetterboxGui:new(target, custom_mt)
	if custom_mt == nil then
		custom_mt = LetterboxGui_mt;
	end;
	local self = YesNoDialog:new(target, custom_mt);

	return self;
end;

function LetterboxGui:onOpen(element)
	LetterboxGui:superClass().onOpen(self, element);
end;

function LetterboxGui:sendTableData(guiLetterTable, guiNumberTable, numberColourIndex, textColourIndex, flagState, boxColourIndex, letterboxTexts)
	self.guiLetterTable = guiLetterTable;
	self.guiNumberTable = guiNumberTable;
	self.flagState = flagState;
	self.letterboxTexts = letterboxTexts;

	self.numberColourIndex = numberColourIndex;
	self.numberColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[numberColourIndex]));
	self.textColourIndex = textColourIndex;
	self.textColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[textColourIndex]));


	self.boxColourIndex = boxColourIndex;
	local boxText = "N/A";
	if boxColourIndex > 0 then
		self.boxColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[boxColourIndex]));
		boxText = letterboxTexts.boxColour;
		self.setBoxColourButton:setDisabled(false);
	else
		self.boxColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[8]));
		self.setBoxColourButton:setDisabled(true);
	end;

	self.textColourSelect:setText(letterboxTexts.textColour);
	self.numberColourSelect:setText(letterboxTexts.numberColour);
	self.boxColourSelect:setText(boxText);

	local numberTableText = {" ", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9"};

	for n = 1, 4 do
		self.setNumber[n]:setTexts(numberTableText);
		self.setNumber[n]:setState(guiNumberTable[n], true);
	end;

	local letterTableText = {"A", "B", "C", "D", "E", "F", "G", "H", "I", "J",
							"K", "L", "M", "N", "O", "P", "Q", "R", "S", "T",
							"U", "V", "W", "X", "Y", "Z", "Ü", "Ä", "Ö", "ß",
							"-", ".", " "};

	for l = 1, 14 do
		self.setLetter[l]:setTexts(letterTableText);
		self.setLetter[l]:setState(guiLetterTable[l], true);
	end;

	if flagState ~= 0 then
		self.flagStateActive = true;
		self.setFlagState:setTexts({letterboxTexts.flagDown, letterboxTexts.flagUp});
		self.setFlagState:setState(flagState, true);
		self.setFlagState:setDisabled(false);
	else
		self.flagStateActive = false;
		self.setFlagState:setTexts({"N/A"});
		self.setFlagState:setState(1, true);
		self.setFlagState:setDisabled(true);
	end;
end;

function LetterboxGui:changeLetterOne(state)
	self.guiLetterTable[1] = state;
end;

function LetterboxGui:changeLetterTwo(state)
	self.guiLetterTable[2] = state;
end;

function LetterboxGui:changeLetterThree(state)
	self.guiLetterTable[3] = state;
end;

function LetterboxGui:changeLetterFour(state)
	self.guiLetterTable[4] = state;
end;

function LetterboxGui:changeLetterFive(state)
	self.guiLetterTable[5] = state;
end;

function LetterboxGui:changeLetterSix(state)
	self.guiLetterTable[6] = state;
end;

function LetterboxGui:changeLetterSeven(state)
	self.guiLetterTable[7] = state;
end;

function LetterboxGui:changeLetterEight(state)
	self.guiLetterTable[8] = state;
end;

function LetterboxGui:changeLetterNine(state)
	self.guiLetterTable[9] = state;
end;

function LetterboxGui:changeLetterTen(state)
	self.guiLetterTable[10] = state;
end;

function LetterboxGui:changeLetterEleven(state)
	self.guiLetterTable[11] = state;
end;

function LetterboxGui:changeLetterTwelve(state)
	self.guiLetterTable[12] = state;
end;

function LetterboxGui:changeLetterThirteen(state)
	self.guiLetterTable[13] = state;
end;

function LetterboxGui:changeLetterFourteen(state)
	self.guiLetterTable[14] = state;
end;

function LetterboxGui:changeNumberOne(state)
	self.guiNumberTable[1] = state;
end;

function LetterboxGui:changeNumberTwo(state)
	self.guiNumberTable[2] = state;
end;

function LetterboxGui:changeNumberThree(state)
	self.guiNumberTable[3] = state;
end;

function LetterboxGui:changeNumberFour(state)
	self.guiNumberTable[4] = state;
end;

function LetterboxGui:selectNumberColour()
	g_gui:showColorPickerDialog({colors = g_vehicleColors, defaultColor = g_vehicleColors[self.numberColourIndex], callback = self.setNumberColour, target = self});
end;

function LetterboxGui:setNumberColour(colourIndex)
	if colourIndex ~= nil then
		self.numberColourIndex = colourIndex;
		self.numberColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[colourIndex]));
	end;
end;

function LetterboxGui:selectTextColour()
	g_gui:showColorPickerDialog({colors = g_vehicleColors, defaultColor = g_vehicleColors[self.textColourIndex], callback = self.setTextColour, target = self});
end;

function LetterboxGui:setTextColour(colourIndex)
	if colourIndex ~= nil then
		self.textColourIndex = colourIndex;
		self.textColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[colourIndex]));
	end;
end;

function LetterboxGui:selectBoxColour()
	if self.boxColourIndex > 0 then
		g_gui:showColorPickerDialog({colors = g_vehicleColors, defaultColor = g_vehicleColors[self.textColourIndex], callback = self.setBoxColour, target = self});
	end;
end;

function LetterboxGui:setBoxColour(colourIndex)
	if colourIndex ~= nil then
		self.boxColourIndex = colourIndex;
		self.boxColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[colourIndex]));
	end;
end;

function LetterboxGui:changeFlagState(state)
	if self.flagStateActive then
		self.flagState = state;
	end;
end;

function LetterboxGui:onClickOk()
	LetterboxGui:superClass().onClickOk(self);

	self:close();
	if self.callback ~= nil then
		if self.target ~= nil then
			local numColour = self.numberColourIndex;
			local textColour = self.textColourIndex;
			local boxColour = self.boxColourIndex;
			self.callback(self.target, self.guiLetterTable, self.guiNumberTable, numColour, textColour, self.flagState, boxColour);
		else
			print("ERROR: [LetterboxGui.lua]  Target is missing.");
		end;
	end;
end;

function LetterboxGui:loadCallback(callback, target)
	self.callback = callback;
	self.target = target;
end;

function LetterboxGui:onClickBack()
	LetterboxGui:superClass().onClickBack(self);
end;

function LetterboxGui:onClickReload()
	for n = 1, 4 do
		self.setNumber[n]:setState(1, true);
	end;
	for l = 1, 14 do
		self.setLetter[l]:setState(33, true);
	end;

	self.numberColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[8]));
	self.numberColourIndex = 8;
	self.textColourSelectBitmap:setImageColor(nil, unpack(g_vehicleColors[8]));
	self.textColourIndex = 8;
end;